@@ -3,8 +3,8 @@ from extras.plugins import PluginConfig
 class NextBoxUIConfig(PluginConfig):
     name = 'nextbox_ui_plugin'
     verbose_name = 'NextBox UI'
-    description = 'Test'
-    version = '0.6.5'
+    description = 'A topology visualization plugin for Netbox powered by NextUI Toolkit.'
+    version = '0.7.0'
     author = 'Igor Korotchenkov'
     author_email = 'iDebugAll@gmail.com'
     base_url = 'nextbox-ui'
